/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * xesam-glib
 * Copyright (C) Mikkel Kamstrup Erlandsen 2007 <mikkel.kamstrup@gmail.com>
 * 
 * xesam-glib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * xesam-glib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with xesam-glib.  If not, write to:
 * 	The Free Software Foundation, Inc.,
 * 	51 Franklin Street, Fifth Floor
 * 	Boston, MA  02110-1301, USA.
 */

#if defined(XESAM_GLIB_ENABLE_SINGLE_INCLUDES) && !defined (_XESAM_GLIB_H_) && !defined (XESAM_GLIB_COMPILATION)
#error "Only <xesam-glib.h> can be included directly."
#endif

#ifndef _XESAM_GLIB_GLOBALS_H_
#define _XESAM_GLIB_GLOBALS_H_

G_BEGIN_DECLS

/**
 * SECTION:xesam-glib-globals
 * @short_description: Definitions of commonly used names
 *
 * 
 */

/**
 * XESAM_G_SERVER_DBUS_NAME
 *
 * DBus name for the main search engine as defined by the Xesam specification
 */
#define XESAM_G_SERVER_DBUS_NAME "org.freedesktop.xesam.searcher"

/**
 * XESAM_G_SERVER_DBUS_INTERFACE
 *
 * DBus interface as defined in the Xesam specification
 */
#define XESAM_G_SERVER_DBUS_INTERFACE "org.freedesktop.xesam.Search"

/**
 * XESAM_G_SERVER_DBUS_OBJECT
 *
 * DBus object path for the main searcher as defined in the Xesam specification
 */
#define XESAM_G_SERVER_DBUS_OBJECT "/org/freedesktop/xesam/searcher/main"

/* Session methods */

/**
 * XESAM_G_METHOD_NewSession
 *
 * The name of the NewSession method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_NewSession 	"NewSession"

/**
 * XESAM_G_METHOD_CloseSession
 *
 * The name of the CloseSession method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_CloseSession "CloseSession"

/**
 * XESAM_G_METHOD_GetProperty
 *
 * The name of the GetProperty method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_GetProperty 	"GetProperty"

/**
 * XESAM_G_METHOD_SetProperty
 *
 * The name of the SetProperty method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_SetProperty 	"SetProperty"

/* Search methods and signals */

/**
 * XESAM_G_METHOD_NewSearch
 *
 * The name of the NewSearch method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_NewSearch 	"NewSearch"

/**
 * XESAM_G_METHOD_StartSearch
 *
 * The name of the StartSearch method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_StartSearch 	"StartSearch"

/**
 * XESAM_G_METHOD_CloseSearch
 *
 * The name of the CloseSearch method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_CloseSearch 	"CloseSearch"

/**
 * XESAM_G_METHOD_GetHits
 *
 * The name of the GetHits method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_GetHits 		"GetHits"

/**
 * XESAM_G_METHOD_GetHitData
 *
 * The name of the GetHitData method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_GetHitData 	"GetHitData"

/**
 * XESAM_G_METHOD_GetHitCount
 *
 * The name of the GetHitCount method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_GetHitCount 	"GetHitCount"

/**
 * XESAM_G_SIGNAL_HitsAdded
 *
 * The name of the HitsAdded signal in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_SIGNAL_HitsAdded 	"HitsAdded"

/**
 * XESAM_G_SIGNAL_HitsModified
 *
 * The name of the HitsModified signal in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_SIGNAL_HitsModified "HitsModified"

/**
 * XESAM_G_SIGNAL_HitsRemoved
 *
 * The name of the HitsRemoved signal in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_SIGNAL_HitsRemoved 	"HitsRemoved"

/**
 * XESAM_G_SIGNAL_SearchDone
 *
 * The name of the SearchDone signal in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_SIGNAL_SearchDone 	"SearchDone"

/* State info methods */
/**
 * XESAM_G_METHOD_GetState
 *
 * The name of the GetState method in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_METHOD_GetState 	"GetState"

/**
 * XESAM_G_SIGNAL_StateChanged
 *
 * The name of the StateChanged signal in the Xesam search specification.
 * Provided here to grant compile-time safety for consumers.
 */
#define XESAM_G_SIGNAL_StateChanged "StateChanged"

/* GError definitions */
#define XESAM_G_ERROR xesam_g_error_quark ()
#define XESAM_G_DBUS_ERROR xesam_g_dbus_error_quark ()
GQuark xesam_g_error_quark (void);

G_END_DECLS

#endif /* _XESAM_GLIB_GLOBALS_H_ */
